Module: Google::Cloud::ArtifactRegistry
- Defined in:
- lib/google/cloud/artifact_registry.rb,
lib/google/cloud/artifact_registry/version.rb
Constant Summary collapse
- VERSION =
"2.2.0"
Class Method Summary collapse
-
.artifact_registry(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for ArtifactRegistry.
-
.artifact_registry_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the ArtifactRegistry service is supported by the current client.
-
.configure {|::Google::Cloud.configure.artifact_registry| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-artifact_registry library.
Class Method Details
.artifact_registry(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for ArtifactRegistry.
By default, this returns an instance of
Google::Cloud::ArtifactRegistry::V1::ArtifactRegistry::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the ArtifactRegistry service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the ArtifactRegistry service. You can determine whether the method will succeed by calling artifact_registry_available?.
About ArtifactRegistry
The Artifact Registry API service.
Artifact Registry is an artifact management system for storing artifacts from different package management systems.
The resources managed by this API are:
- Repositories, which group packages and their data.
- Packages, which group versions and their tags.
- Versions, which are specific forms of a package.
- Tags, which represent alternative names for versions.
- Files, which contain content and are optionally associated with a Package or Version.
87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/google/cloud/artifact_registry.rb', line 87 def self.artifact_registry version: :v1, transport: :grpc, &block require "google/cloud/artifact_registry/#{version.to_s.downcase}" package_name = Google::Cloud::ArtifactRegistry .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::ArtifactRegistry.const_get(package_name).const_get(:ArtifactRegistry) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.artifact_registry_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the ArtifactRegistry service is supported by the current client. If true, you can retrieve a client object by calling artifact_registry. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the ArtifactRegistry service, or if the versioned client gem needs an update to support the ArtifactRegistry service.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/google/cloud/artifact_registry.rb', line 111 def self.artifact_registry_available? version: :v1, transport: :grpc require "google/cloud/artifact_registry/#{version.to_s.downcase}" package_name = Google::Cloud::ArtifactRegistry .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::ArtifactRegistry.const_get package_name return false unless service_module.const_defined? :ArtifactRegistry service_module = service_module.const_get :ArtifactRegistry if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.configure {|::Google::Cloud.configure.artifact_registry| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-artifact_registry library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional headers to be sent with the call.retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys::initial_delay(type:Numeric) - The initial delay in seconds.:max_delay(type:Numeric) - The max delay in seconds.:multiplier(type:Numeric) - The incremental backoff multiplier.:jitter(type:Numeric) - The jitter in seconds. Default: 1.0.:retry_codes(type:Array<String>) - The error codes that should trigger a retry.
159 160 161 162 163 |
# File 'lib/google/cloud/artifact_registry.rb', line 159 def self.configure yield ::Google::Cloud.configure.artifact_registry if block_given? ::Google::Cloud.configure.artifact_registry end |